@@ -15,39 +15,33 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
 
-from google.cloud.datalabeling_v1beta1.types import annotation_spec_set
+from google.cloud.datalabeling_v1beta1 import gapic_version as package_version
 from google.cloud.datalabeling_v1beta1.types import (
     annotation_spec_set as gcd_annotation_spec_set,
 )
+from google.cloud.datalabeling_v1beta1.types import evaluation_job as gcd_evaluation_job
+from google.cloud.datalabeling_v1beta1.types import annotation_spec_set
 from google.cloud.datalabeling_v1beta1.types import data_labeling_service
 from google.cloud.datalabeling_v1beta1.types import dataset
 from google.cloud.datalabeling_v1beta1.types import dataset as gcd_dataset
 from google.cloud.datalabeling_v1beta1.types import evaluation
 from google.cloud.datalabeling_v1beta1.types import evaluation_job
-from google.cloud.datalabeling_v1beta1.types import evaluation_job as gcd_evaluation_job
 from google.cloud.datalabeling_v1beta1.types import instruction
-from google.longrunning import operations_pb2  # type: ignore
-from google.protobuf import empty_pb2  # type: ignore
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-datalabeling",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 class DataLabelingServiceTransport(abc.ABC):
@@ -61,12 +55,13 @@ class DataLabelingServiceTransport(abc.ABC):
         self,
         *,
         host: str = DEFAULT_HOST,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -93,10 +88,6 @@ class DataLabelingServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -118,6 +109,11 @@ class DataLabelingServiceTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -130,11 +126,18 @@ class DataLabelingServiceTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.create_dataset: gapic_v1.method.wrap_method(
-                self.create_dataset, default_timeout=30.0, client_info=client_info,
+                self.create_dataset,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.get_dataset: gapic_v1.method.wrap_method(
                 self.get_dataset,
@@ -182,7 +185,9 @@ class DataLabelingServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.import_data: gapic_v1.method.wrap_method(
-                self.import_data, default_timeout=30.0, client_info=client_info,
+                self.import_data,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.export_data: gapic_v1.method.wrap_method(
                 self.export_data,
@@ -265,13 +270,19 @@ class DataLabelingServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.label_image: gapic_v1.method.wrap_method(
-                self.label_image, default_timeout=30.0, client_info=client_info,
+                self.label_image,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.label_video: gapic_v1.method.wrap_method(
-                self.label_video, default_timeout=30.0, client_info=client_info,
+                self.label_video,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.label_text: gapic_v1.method.wrap_method(
-                self.label_text, default_timeout=30.0, client_info=client_info,
+                self.label_text,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.get_example: gapic_v1.method.wrap_method(
                 self.get_example,
@@ -354,7 +365,9 @@ class DataLabelingServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_instruction: gapic_v1.method.wrap_method(
-                self.create_instruction, default_timeout=30.0, client_info=client_info,
+                self.create_instruction,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.get_instruction: gapic_v1.method.wrap_method(
                 self.get_instruction,
@@ -506,9 +519,9 @@ class DataLabelingServiceTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -859,5 +872,9 @@ class DataLabelingServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("DataLabelingServiceTransport",)
