@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -50,10 +52,15 @@ class DataType(proto.Enum):
 
     Values:
         DATA_TYPE_UNSPECIFIED (0):
+            No description available.
         IMAGE (1):
+            Allowed for continuous evaluation.
         VIDEO (2):
+            No description available.
         TEXT (4):
+            Allowed for continuous evaluation.
         GENERAL_DATA (6):
+            Allowed for continuous evaluation.
     """
     DATA_TYPE_UNSPECIFIED = 0
     IMAGE = 1
