@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -110,7 +112,7 @@ class EvaluationJob(proto.Message):
 
         Values:
             STATE_UNSPECIFIED (0):
-
+                No description available.
             SCHEDULED (1):
                 The job is scheduled to run at the [configured
                 interval][google.cloud.datalabeling.v1beta1.EvaluationJob.schedule].
